==> vue-alert-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/alert/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning, iconChevronDown } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["icon", "type", "size", "description", "title", "closable", "center", "showIcon", "closeText", "singleLine", "scrolling", "showFoldable"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning(),
    IconChevronDown: iconChevronDown()
  },
  emits: ["close"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", [_vm.state.show ? _c("div", {
    class: ["min-h-min flex py-2 sm:py-3 px-4 my-2 rounded box-border font-light sm:font-normal", {
      "bg-color-info-secondary-subtle": _vm.type === "info" || !_vm.type
    }, {
      "bg-color-error-subtler": _vm.type === "error"
    }, {
      "bg-color-warning-subtler": _vm.type === "warning"
    }, {
      "bg-color-success-subtler": _vm.type === "success"
    }, {
      "text-center": _vm.center
    }]
  }, [_vm.showIcon ? _c(_vm.state.getIcon, {
    tag: "component",
    class: [{
      "text-color-info-secondary": _vm.type === "info" || !_vm.type
    }, {
      "text-color-error": _vm.type === "error"
    }, {
      "text-color-warning": _vm.type === "warning"
    }, {
      "text-color-success": _vm.type === "success"
    }],
    attrs: {
      "custom-class": "h-4.5 w-4.5 mt-1 sm:mt-0.5 sm:h-6 sm:w-5 sm:h-5 fill-current"
    }
  }) : _vm._e(), _vm.showFoldable ? _c("div", {
    staticClass: "flex-1 leading-6 text-sm overflow-hidden",
    class: _vm.showIcon ? "mx-2" : "mr-2"
  }, [_vm.size === "large" ? _c("div", {
    staticClass: "inline-flex cursor-pointer font-medium",
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_c("span", [_vm._t("title", [_vm._v(_vm._s(_vm.state.getTitle))])], 2), _c("span", {
    staticClass: "ml-2.5"
  }, [_c("icon-chevron-down", {
    staticClass: "transition-transform duration-300 align-top my-1 fill-color-icon-placeholder",
    class: [_vm.state.contentVisible ? "rotate-180" : "rotate-0"]
  })], 1)]) : _vm._e(), _c("div", {
    ref: "ContentDescribe",
    class: ["transition-all duration-900 ease-linear", {
      "hidden": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }, {
      "overflow-y-auto": _vm.state.scrollStatus
    }, _vm.state.contentVisible ? "max-h-[theme(spacing.72)]" : "max-h-0"]
  }, [_c("div", {
    class: [{
      "truncate": _vm.singleLine
    }, {
      "hover:animate-[leftMove_10s_linear_infinite] hover:overflow-visible cursor-pointer": _vm.singleLine && _vm.scrolling
    }]
  }, [_vm._t("description", [_vm._v(_vm._s(_vm.description))])], 2)]), _vm.size === "large" && _vm.slots.default ? _c("div", {
    ref: "ContentDefault",
    class: ["transition-all duration-900 ease-linear", {
      "pt-2": _vm.description && _vm.state.contentVisible
    }, {
      "overflow-y-auto": _vm.state.scrollStatus
    }, _vm.state.contentVisible ? "max-h-[theme(spacing.72)]" : "max-h-0"]
  }, [_vm._t("default")], 2) : _vm._e()]) : _c("div", {
    staticClass: "flex-1 leading-6 text-sm overflow-hidden cursor-pointer",
    class: _vm.showIcon ? "mx-2" : "mr-2"
  }, [_vm.size === "large" ? _c("div", {
    staticClass: "font-medium"
  }, [_vm._t("title", [_vm._v(_vm._s(_vm.state.getTitle))])], 2) : _vm._e(), _c("div", {
    class: [{
      "hidden": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }]
  }, [_c("div", {
    class: [{
      "truncate": _vm.singleLine
    }, {
      "hover:animate-[leftMove_10s_linear_infinite] hover:overflow-visible cursor-pointer": _vm.singleLine && _vm.scrolling
    }]
  }, [_vm._t("description", [_vm._v(_vm._s(_vm.description))])], 2)]), _vm.size === "large" && _vm.slots.default ? _c("div", {
    staticClass: "pt-2"
  }, [_vm._t("default")], 2) : _vm._e()]), !_vm.closeText && _vm.closable ? _c("icon-close", {
    staticClass: "h-4 w-4 mt-1 cursor-pointer fill-color-text-primary opacity-70",
    on: {
      "click": _vm.handleClose
    }
  }) : _vm.closeText && _vm.closable ? _c("span", {
    staticClass: "leading-6 text-sm cursor-pointer",
    on: {
      "click": _vm.handleClose
    }
  }, [_vm._v(_vm._s(_vm.closeText))]) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-alert-2.21.1.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/alert/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning, iconChevronDown } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["close"],
  props: [].concat(props, ["icon", "type", "size", "description", "title", "closable", "center", "showIcon", "showTitle", "closeText", "singleLine", "scrolling", "showFoldable", "customClass"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning(),
    IconChevronDown: iconChevronDown()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", [_vm.state.show ? _c("div", {
    class: _vm.m("min-h-min flex py-2 sm:py-3 px-4 my-2 rounded box-border font-light sm:font-normal text-color-text-primary", {
      "bg-color-info-primary-subtler": _vm.type === "info" || !_vm.type
    }, {
      "bg-color-error-subtler": _vm.type === "error"
    }, {
      "bg-color-warning-subtler": _vm.type === "warning"
    }, {
      "bg-color-success-subtler": _vm.type === "success"
    }, {
      "text-center": _vm.center
    }, _vm.customClass),
    attrs: {
      "data-tag": "tiny-alert"
    }
  }, [_vm.showIcon ? _c(_vm.state.getIcon, {
    tag: "component",
    class: [{
      "text-color-info-primary": _vm.type === "info" || !_vm.type
    }, {
      "text-color-error": _vm.type === "error"
    }, {
      "text-color-warning": _vm.type === "warning"
    }, {
      "text-color-success": _vm.type === "success"
    }],
    attrs: {
      "custom-class": "h-4.5 w-4.5 mt-1 sm:mt-0.5 sm:h-6 sm:w-5 sm:h-5 fill-current"
    }
  }) : _vm._e(), _vm.showFoldable ? _c("div", {
    staticClass: "flex-1 leading-6 text-sm overflow-hidden",
    class: _vm.showIcon ? "mx-2" : "mr-2",
    attrs: {
      "data-tag": "tiny-alert-foldable"
    }
  }, [_vm.size === "large" && _vm.showTitle ? _c("div", {
    staticClass: "inline-flex cursor-pointer font-medium",
    attrs: {
      "data-tag": "tiny-alert-large"
    },
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_c("span", {
    attrs: {
      "data-tag": "tiny-alert-title"
    }
  }, [_vm._t("title", function() {
    return [_vm._v(_vm._s(_vm.state.getTitle))];
  })], 2), _c("span", {
    staticClass: "ml-2.5",
    attrs: {
      "data-tag": "tiny-alert-icon"
    }
  }, [_c("icon-chevron-down", {
    staticClass: "transition-transform duration-300 align-top my-1 fill-color-icon-placeholder",
    class: [_vm.state.contentVisible ? "rotate-180" : "rotate-0"]
  })], 1)]) : _vm._e(), _c("div", {
    ref: "ContentDescribe",
    class: ["transition-all duration-900 ease-linear", {
      "hidden": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }, {
      "overflow-y-auto": _vm.state.scrollStatus
    }, _vm.state.contentVisible ? "max-h-[theme(spacing.72)]" : "max-h-0"],
    attrs: {
      "data-tag": "tiny-alert-content"
    }
  }, [_c("div", {
    staticClass: "text-color-text-secondary",
    class: [{
      "truncate": _vm.singleLine
    }, {
      "hover:animate-[leftMove_10s_linear_infinite] hover:overflow-visible cursor-pointer": _vm.singleLine && _vm.scrolling
    }],
    attrs: {
      "data-tag": "tiny-alert-singline"
    }
  }, [_vm._t("description", function() {
    return [_vm._v(_vm._s(_vm.description))];
  })], 2)]), _vm.size === "large" && _vm.slots.default ? _c("div", {
    ref: "ContentDefault",
    class: ["transition-all duration-900 ease-linear", {
      "pt-2": _vm.description && _vm.state.contentVisible
    }, {
      "overflow-y-auto": _vm.state.scrollStatus
    }, _vm.state.contentVisible ? "max-h-[theme(spacing.72)]" : "max-h-0"],
    attrs: {
      "data-tag": "tiny-alert-default"
    }
  }, [_vm._t("default")], 2) : _vm._e()]) : _c("div", {
    staticClass: "flex-1 leading-6 text-sm overflow-hidden cursor-pointer",
    class: [_vm.showIcon ? "ml-2" : "", _vm.closable ? "mr-2" : ""],
    attrs: {
      "data-tag": "tiny-alert-notfoldable"
    }
  }, [_vm.size === "large" && _vm.showTitle ? _c("div", {
    staticClass: "font-medium",
    attrs: {
      "data-tag": "tiny-alert-large"
    }
  }, [_vm._t("title", function() {
    return [_vm._v(_vm._s(_vm.state.getTitle) + " ")];
  })], 2) : _vm._e(), _c("div", {
    class: [{
      "hidden": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }],
    attrs: {
      "data-tag": "tiny-alert-singlelinebox"
    }
  }, [_c("div", {
    class: [{
      "truncate": _vm.singleLine
    }, {
      "hover:animate-[leftMove_10s_linear_infinite] hover:overflow-visible cursor-pointer": _vm.singleLine && _vm.scrolling
    }],
    attrs: {
      "data-tag": "tiny-alert-singleline"
    }
  }, [_vm._t("description", function() {
    return [_vm._v(_vm._s(_vm.description))];
  })], 2)]), _vm.size === "large" && _vm.slots.default ? _c("div", {
    staticClass: "pt-2"
  }, [_vm._t("default")], 2) : _vm._e()]), !_vm.closeText && _vm.closable ? _c("icon-close", {
    staticClass: "h-4 w-4 mt-1 cursor-pointer fill-color-text-primary opacity-70",
    on: {
      "click": _vm.handleClose
    }
  }) : _vm.closeText && _vm.closable ? _c("span", {
    staticClass: "leading-6 text-sm cursor-pointer",
    attrs: {
      "data-tag": "tiny-alert-close-text"
    },
    on: {
      "click": _vm.handleClose
    }
  }, [_vm._v(_vm._s(_vm.closeText))]) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
